#
# spec file for package python-hcloud
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hcloud
Version:        1.35.0
Release:        1.1
Summary:        Hetzner Cloud Python library
License:        MIT
URL:            https://github.com/hetznercloud/hcloud-python
Source:         https://files.pythonhosted.org/packages/source/h/hcloud/hcloud-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.7.5
Requires:       python-requests >= 2.20
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.7.5}
BuildRequires:  %{python_module requests >= 2.20}
# /SECTION
%python_subpackages

%description
Official Hetzner Cloud Python library.

%prep
%autosetup -p1 -n hcloud-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest tests/unit/

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/hcloud
%{python_sitelib}/hcloud-%{version}.dist-info

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.35.0:
  * add `include_deprecated` option when fetching images by name
  * raise warnings for the `ImagesClient.get_by_name` deprecation
  * add `has_id_or_name` to `DomainIdentityMixin`
  * invalid type for load balancer private network property
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 1.33.2:
  * publish package to PyPI using OIDC auth
  * private object not exported in top level module
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.33.0:
  * add metrics endpoint for load balancers and servers (#331)
  * fallback to error code when message is unset (#328)
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.32.0:
  * allow returning root_password in servers rebuild (#276)
  * prepare for iso deprecated field removal (#320) (beae328)
  * add deprecation field to Iso (#318) (036b52f)
  * support python 3.12 (#311) (7e8cd1d)
  * prevent api calls when printing bound models (#305) (c1de7ef)
  * add domain attribute type hints to bound models (#300)
  * load token from env in examples scripts (#302) (f18c9a6)
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.28.0:
  * add load balancer target health status field
  * implement resource actions clients
  * missing long_description content_type in setup.py
  * add global request timeout option
  * reexport references in parent ressources modules
  * the package is now typed
  * allow omitting datacenter when creating a primary ip
  * invalid attribute in placement group
  * add repr method to domains
  * drop support for python 3.7
  * add details to raise exceptions
  * move hcloud.hcloud module to hcloud._client
  * revert remove python-dateutil dependency
  * handle Z timezone in ISO8601 datetime format
  * isos: invalid name for include_wildcard_architecture argument
  * network: add field expose_routes_to_vswitch
  * setup exception hierarchy
  * add deprecation field to ServerType
  * adjust label validation for max length of 63 characters
  * server_type: add field for included traffic
  * feat: add support for ARM APIs by @apricote
  * fix: remove unused future dependency by @apricote
  * Remove use of external mock module by @s-t-e-v-e-n-k
  * Add validation helper for Label Values/Keys by @LKaemmerling
- Switch to pyproject macros.
- Drop patch remove-mock.patch, included upstream.
- Stop using greedy globs in %%files.
* Tue Aug  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.17.0:
  * Add suport for primary IPs
- Add patch remove-mock.patch:
  * Use unittest.mock.
* Mon Mar 21 2022 pgajdos@suse.com
- version update to 1.16.0
  v1.16.0 (2021-08-17)
  - --------------------
  * Feature: Add support for Load Balancer DNS PTRs
  v1.15.0 (2021-08-16)
  - --------------------
  * Feature: Add support for Placement Groups
  v1.14.1 (2021-08-10)
  - --------------------
  * Bugfix: Fix crash on extra fields in public_net response
  * Improvement: Format code with black
  v1.14.0 (2021-08-03)
  - --------------------
  * Feature: Add support for Firewall rule descriptions
  v1.13.0 (2021-07-16)
  - --------------------
  * Feature: Add support for Firewall Protocols ESP and GRE
  * Feature: Add support for Image Type APP
  * Feature: Add support for creating Firewalls with Firewalls
  * Feature: Add support for Label Selectors in Firewalls
  * Improvement: Improve handling of underlying TCP connections. Now for every
    client instance a single TCP connection is used instead of one per call.
  * Note: Support for Python 2.7 and Python 3.5 was removed
  v1.12.0 (2021-04-06)
  - --------------------
  * Feature: Add support for managed Certificates
  v1.11.0 (2021-03-11)
  - --------------------
  * Feature: Add support for Firewalls
  * Feature: Add `primary_disk_size` to `Server` Domain
  v1.10.0 (2020-11-03)
  - --------------------
  * Feature: Add `include_deprecated` filter to `get_list` and `get_all` on `ImagesClient`
  * Feature: Add vSwitch support to `add_subnet` on `NetworksClient`
  * Feature: Add subnet type constants to `NetworkSubnet` domain
    (`NetworkSubnet.TYPE_CLOUD`, `NetworkSubnet.TYPE_VSWITCH`)
  v1.9.1 (2020-08-11)
  - -------------------
  * Bugfix: BoundLoadBalancer serialization failed when using IP targets
  v1.9.0 (2020-08-10)
  - -------------------
  * Feature: Add `included_traffic`, `outgoing_traffic` and `ingoing_traffic`
    properties to Load Balancer domain
  * Feature: Add `change_type`-method to `LoadBalancersClient`
  * Feature: Add support for `LoadBalancerTargetLabelSelector`
  * Feature: Add support for `LoadBalancerTargetLabelSelector`
  v1.8.2 (2020-07-20)
  - -------------------
  * Fix: Loosen up the requirements.
- do not require python-mock for testing
* Sat Aug 15 2020 John Vandenberg <jayvdb@gmail.com>
- Tidy spec
* Sat Jul 11 2020 mig4@auril.club
- Initial package version 1.8.1
